@@ -1,11 +1,14 @@
 #!/usr/bin/python$
 # __main__.py
 
+import os
+import sys
+file_dir = os.path.dirname(__file__)
+sys.path.append(file_dir)
+
 import argparse
 import subprocess
-import os
 #import numpy
-import sys
 #import multiprocessing as mp
 from gen_tree_overlappingCNA import gen_tree
 #from gen_readcount import gen_readcount
